@@ -1407,10 +1407,20 @@ def create_super_district_coupled_network(coupling_density, heat_sidelane_size=2
 
 
 def generate_multi_network_based_on_simbench(
-    simbench_id, heat_deployment_rate, gas_deployment_rate, coupling_density=0.3
+    simbench_id,
+    heat_deployment_rate,
+    gas_deployment_rate,
+    chp_density=0.3,
+    p2g_density=0.1,
+    p2h_density=0.1,
 ):
     return generate_multi_network_based_on_power_net(
-        simbench.get_simbench_net(simbench_id)
+        simbench.get_simbench_net(simbench_id),
+        heat_deployment_rate,
+        gas_deployment_rate,
+        chp_density=chp_density,
+        p2g_density=p2g_density,
+        p2h_density=p2h_density,
     )
 
 
