@@ -16,3 +16,9 @@ def test_generate_network_based_on_power():
     mn = ps.generate_multi_network_based_on_power_net(pp_net, 1 / 2, 1 / 3)
 
     assert mn is not None
+
+
+def test_generate_network_based_on_power_conv():
+    mn = ps.generate_multi_network_based_on_simbench("1-MV-urban--1-no_sw", 1, 1)
+
+    assert mn is not None
